/* link-personas.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from link-personas.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <folks/folks-eds.h>


#define TYPE_LINKING_METHOD (linking_method_get_type ())

#define TYPE_LINK_PERSONAS_TESTS (link_personas_tests_get_type ())
#define LINK_PERSONAS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LINK_PERSONAS_TESTS, LinkPersonasTests))
#define LINK_PERSONAS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LINK_PERSONAS_TESTS, LinkPersonasTestsClass))
#define IS_LINK_PERSONAS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LINK_PERSONAS_TESTS))
#define IS_LINK_PERSONAS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LINK_PERSONAS_TESTS))
#define LINK_PERSONAS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LINK_PERSONAS_TESTS, LinkPersonasTestsClass))

typedef struct _LinkPersonasTests LinkPersonasTests;
typedef struct _LinkPersonasTestsClass LinkPersonasTestsClass;
typedef struct _LinkPersonasTestsPrivate LinkPersonasTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _eds_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (eds_test_backend_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _LinkPersonasTestsTestLinkingPersonasAsyncData LinkPersonasTestsTestLinkingPersonasAsyncData;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _LinkPersonasTestsAddPersonasData LinkPersonasTestsAddPersonasData;
typedef struct _LinkPersonasTestsCheckPersonasData LinkPersonasTestsCheckPersonasData;
typedef struct _LinkPersonasTestsCheckAutoLinkedPersonasData LinkPersonasTestsCheckAutoLinkedPersonasData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	LINKING_METHOD_IM_ADDRESSES,
	LINKING_METHOD_LOCAL_IDS,
	LINKING_METHOD_WEB_SERVICE_ADDRESSES,
	LINKING_METHOD_EMAIL_AS_IM_ADDRESS
} LinkingMethod;

struct _LinkPersonasTests {
	EdsTestTestCase parent_instance;
	LinkPersonasTestsPrivate * priv;
};

struct _LinkPersonasTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _LinkPersonasTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname_1;
	gchar* _persona_fullname_2;
	gchar* _im_address_1;
	gchar* _im_address_2;
	gchar* _auto_linkable_email;
	gboolean _linking_fired;
	gboolean _persona_found_1;
	gboolean _persona_found_2;
	gchar* _persona_iid_1;
	gchar* _persona_iid_2;
	GeeHashSet* _personas;
	GeeHashMap* _linking_props;
	LinkingMethod _linking_method;
	gint _test_num;
};

struct _LinkPersonasTestsTestLinkingPersonasAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksPersonaStore* pstore;
	EdsTestBackend* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	FolksPersonaStore* _tmp7_;
	FolksPersonaStore* _tmp8_;
	FolksPersonaStore* _tmp9_;
	FolksPersonaStore* _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	FolksPersonaStore* _tmp13_;
	FolksPersonaStore* _tmp14_;
	GError* e;
	GError* _tmp15_;
	const gchar* _tmp16_;
	GError * _inner_error_;
};

struct _LinkPersonasTestsAddPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasTests* self;
	FolksPersonaStore* pstore1;
	FolksPersonaStore* pstore2;
	GHashTable* details1;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GValue* v1;
	gchar* wsk;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gboolean _tmp5_;
	LinkingMethod _tmp6_;
	LinkingMethod _tmp7_;
	GValue _tmp8_;
	GValue _tmp9_;
	GValue* _tmp10_;
	GeeHashMultiMap* im_addrs1;
	GeeHashMultiMap* _tmp11_;
	LinkingMethod _tmp12_;
	GeeHashMultiMap* _tmp13_;
	const gchar* _tmp14_;
	FolksImFieldDetails* _tmp15_;
	FolksImFieldDetails* _tmp16_;
	GeeHashMultiMap* _tmp17_;
	const gchar* _tmp18_;
	FolksImFieldDetails* _tmp19_;
	FolksImFieldDetails* _tmp20_;
	GValue* _tmp21_;
	GeeHashMultiMap* _tmp22_;
	GHashTable* _tmp23_;
	gchar* _tmp24_;
	GValue* _tmp25_;
	LinkingMethod _tmp26_;
	GValue _tmp27_;
	GValue _tmp28_;
	GValue* _tmp29_;
	GeeHashMultiMap* wsa1;
	GeeHashMultiMap* _tmp30_;
	GeeHashMultiMap* _tmp31_;
	const gchar* _tmp32_;
	FolksWebServiceFieldDetails* _tmp33_;
	FolksWebServiceFieldDetails* _tmp34_;
	GValue* _tmp35_;
	GeeHashMultiMap* _tmp36_;
	GHashTable* _tmp37_;
	const gchar* _tmp38_;
	gchar* _tmp39_;
	GValue* _tmp40_;
	GValue* v2;
	GValue _tmp41_;
	GValue _tmp42_;
	GValue* _tmp43_;
	GValue* _tmp44_;
	GValue* _tmp45_;
	const gchar* _tmp46_;
	GHashTable* _tmp47_;
	gchar* _tmp48_;
	GValue* _tmp49_;
	GHashTable* details2;
	GHashFunc _tmp50_;
	GEqualFunc _tmp51_;
	GHashTable* _tmp52_;
	GValue* v3;
	LinkingMethod _tmp53_;
	GValue _tmp54_;
	GValue _tmp55_;
	GValue* _tmp56_;
	GeeHashMultiMap* im_addrs2;
	GeeHashMultiMap* _tmp57_;
	GeeHashMultiMap* _tmp58_;
	const gchar* _tmp59_;
	FolksImFieldDetails* _tmp60_;
	FolksImFieldDetails* _tmp61_;
	GValue* _tmp62_;
	GeeHashMultiMap* _tmp63_;
	GHashTable* _tmp64_;
	gchar* _tmp65_;
	GValue* _tmp66_;
	LinkingMethod _tmp67_;
	GValue _tmp68_;
	GValue _tmp69_;
	GValue* _tmp70_;
	GeeHashMultiMap* wsa2;
	GeeHashMultiMap* _tmp71_;
	GeeHashMultiMap* _tmp72_;
	const gchar* _tmp73_;
	FolksWebServiceFieldDetails* _tmp74_;
	FolksWebServiceFieldDetails* _tmp75_;
	GValue* _tmp76_;
	GeeHashMultiMap* _tmp77_;
	GHashTable* _tmp78_;
	const gchar* _tmp79_;
	gchar* _tmp80_;
	GValue* _tmp81_;
	LinkingMethod _tmp82_;
	GValue _tmp83_;
	GValue _tmp84_;
	GValue* _tmp85_;
	GeeHashSet* emails;
	GeeHashSet* _tmp86_;
	FolksEmailFieldDetails* email_1;
	const gchar* _tmp87_;
	FolksEmailFieldDetails* _tmp88_;
	GeeHashSet* _tmp89_;
	FolksEmailFieldDetails* _tmp90_;
	GValue* _tmp91_;
	GeeHashSet* _tmp92_;
	GHashTable* _tmp93_;
	const gchar* _tmp94_;
	gchar* _tmp95_;
	GValue* _tmp96_;
	GValue* v4;
	GValue _tmp97_;
	GValue _tmp98_;
	GValue* _tmp99_;
	GValue* _tmp100_;
	GValue* _tmp101_;
	const gchar* _tmp102_;
	GHashTable* _tmp103_;
	gchar* _tmp104_;
	GValue* _tmp105_;
	FolksIndividualAggregator* _tmp106_;
	FolksPersonaStore* _tmp107_;
	GHashTable* _tmp108_;
	FolksPersona* _tmp109_;
	FolksPersona* _tmp110_;
	FolksIndividualAggregator* _tmp111_;
	FolksPersonaStore* _tmp112_;
	GHashTable* _tmp113_;
	FolksPersona* _tmp114_;
	FolksPersona* _tmp115_;
	GError* e;
	GError* _tmp116_;
	const gchar* _tmp117_;
	GError * _inner_error_;
};

struct _LinkPersonasTestsCheckPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasTests* self;
	FolksIndividual* i;
	gboolean _tmp0_;
	GeeHashMap* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	gboolean _tmp4_;
	FolksPersona* first_persona;
	GeeIterator* _p_it;
	FolksIndividual* _tmp5_;
	GeeSet* _tmp6_;
	GeeSet* _tmp7_;
	GeeIterator* _tmp8_;
	GeeIterator* _tmp9_;
	gboolean _tmp10_;
	FolksPersona* p;
	GeeIterator* _tmp11_;
	gpointer _tmp12_;
	FolksPersona* _tmp13_;
	FolksPersona* _tmp14_;
	gboolean _tmp15_;
	FolksIndividual* _tmp16_;
	const gchar* _tmp17_;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
	const gchar* _tmp20_;
	FolksPersona* _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	gchar* _tmp24_;
	GeeHashSet* _tmp25_;
	FolksPersona* _tmp26_;
	LinkingMethod _tmp27_;
	gchar* contact_id1;
	FolksPersona* _tmp28_;
	const gchar* _tmp29_;
	const gchar* _tmp30_;
	gchar* _tmp31_;
	GeeHashMap* _tmp32_;
	const gchar* _tmp33_;
	gboolean _tmp34_;
	FolksIndividual* _tmp35_;
	const gchar* _tmp36_;
	const gchar* _tmp37_;
	const gchar* _tmp38_;
	const gchar* _tmp39_;
	FolksPersona* _tmp40_;
	const gchar* _tmp41_;
	const gchar* _tmp42_;
	gchar* _tmp43_;
	GeeHashSet* _tmp44_;
	FolksPersona* _tmp45_;
	LinkingMethod _tmp46_;
	gchar* contact_id2;
	FolksPersona* _tmp47_;
	const gchar* _tmp48_;
	const gchar* _tmp49_;
	gchar* _tmp50_;
	GeeHashMap* _tmp51_;
	const gchar* _tmp52_;
	FolksIndividual* _tmp53_;
	GeeSet* _tmp54_;
	GeeSet* _tmp55_;
	gint _tmp56_;
	gint _tmp57_;
	LinkingMethod _tmp58_;
	GeeIterator* _proto_it;
	FolksIndividual* _tmp59_;
	GeeMultiMap* _tmp60_;
	GeeMultiMap* _tmp61_;
	GeeSet* _tmp62_;
	GeeSet* _tmp63_;
	GeeIterator* _tmp64_;
	GeeIterator* _tmp65_;
	GeeIterator* _tmp66_;
	gboolean _tmp67_;
	gchar* proto;
	GeeIterator* _tmp68_;
	gpointer _tmp69_;
	GeeCollection* im_fds;
	FolksIndividual* _tmp70_;
	GeeMultiMap* _tmp71_;
	GeeMultiMap* _tmp72_;
	const gchar* _tmp73_;
	GeeCollection* _tmp74_;
	GeeIterator* _im_fd_it;
	GeeCollection* _tmp75_;
	GeeIterator* _tmp76_;
	GeeIterator* _tmp77_;
	gboolean _tmp78_;
	FolksImFieldDetails* im_fd;
	GeeIterator* _tmp79_;
	gpointer _tmp80_;
	FolksImFieldDetails* _tmp81_;
	gconstpointer _tmp82_;
	const gchar* _tmp83_;
	GeeHashMap* _tmp84_;
	gpointer _tmp85_;
	gchar* _tmp86_;
	gboolean _tmp87_;
	GeeHashMap* _tmp88_;
	FolksImFieldDetails* _tmp89_;
	gconstpointer _tmp90_;
	const gchar* _tmp91_;
	GeeHashMap* _tmp92_;
	gpointer _tmp93_;
	gchar* _tmp94_;
	gboolean _tmp95_;
	GeeHashMap* _tmp96_;
	LinkingMethod _tmp97_;
	GeeIterator* _local_id_it;
	FolksIndividual* _tmp98_;
	GeeSet* _tmp99_;
	GeeSet* _tmp100_;
	GeeIterator* _tmp101_;
	GeeIterator* _tmp102_;
	gboolean _tmp103_;
	gchar* local_id;
	GeeIterator* _tmp104_;
	gpointer _tmp105_;
	const gchar* _tmp106_;
	GeeHashMap* _tmp107_;
	gpointer _tmp108_;
	gchar* _tmp109_;
	gboolean _tmp110_;
	GeeHashMap* _tmp111_;
	const gchar* _tmp112_;
	GeeHashMap* _tmp113_;
	gpointer _tmp114_;
	gchar* _tmp115_;
	gboolean _tmp116_;
	GeeHashMap* _tmp117_;
	LinkingMethod _tmp118_;
	GeeIterator* _service_it;
	FolksIndividual* _tmp119_;
	GeeMultiMap* _tmp120_;
	GeeMultiMap* _tmp121_;
	GeeSet* _tmp122_;
	GeeSet* _tmp123_;
	GeeIterator* _tmp124_;
	GeeIterator* _tmp125_;
	GeeIterator* _tmp126_;
	gboolean _tmp127_;
	gchar* service;
	GeeIterator* _tmp128_;
	gpointer _tmp129_;
	GeeCollection* ws_fds;
	FolksIndividual* _tmp130_;
	GeeMultiMap* _tmp131_;
	GeeMultiMap* _tmp132_;
	const gchar* _tmp133_;
	GeeCollection* _tmp134_;
	GeeIterator* _ws_fd_it;
	GeeCollection* _tmp135_;
	GeeIterator* _tmp136_;
	GeeIterator* _tmp137_;
	gboolean _tmp138_;
	FolksWebServiceFieldDetails* ws_fd;
	GeeIterator* _tmp139_;
	gpointer _tmp140_;
	gchar* prop1;
	GeeHashMap* _tmp141_;
	gpointer _tmp142_;
	gchar* prop2;
	GeeHashMap* _tmp143_;
	gpointer _tmp144_;
	gboolean _tmp145_;
	const gchar* _tmp146_;
	FolksWebServiceFieldDetails* _tmp147_;
	const gchar* _tmp148_;
	FolksWebServiceFieldDetails* _tmp149_;
	FolksWebServiceFieldDetails* _tmp150_;
	gboolean _tmp151_;
	GeeHashMap* _tmp152_;
	gboolean _tmp153_;
	const gchar* _tmp154_;
	FolksWebServiceFieldDetails* _tmp155_;
	const gchar* _tmp156_;
	FolksWebServiceFieldDetails* _tmp157_;
	FolksWebServiceFieldDetails* _tmp158_;
	gboolean _tmp159_;
	GeeHashMap* _tmp160_;
	GeeHashMap* _tmp161_;
	gint _tmp162_;
	gint _tmp163_;
	gboolean _tmp164_;
	GeeHashSet* _tmp165_;
	gint _tmp166_;
	gint _tmp167_;
	gboolean _tmp168_;
	FolksIndividualAggregator* _tmp169_;
	GeeHashSet* _tmp170_;
	GError* e;
	GError* _tmp171_;
	const gchar* _tmp172_;
	GError * _inner_error_;
};

struct _LinkPersonasTestsCheckAutoLinkedPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasTests* self;
	FolksIndividual* i;
	GeeHashMap* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	FolksIndividual* _tmp3_;
	GeeSet* _tmp4_;
	GeeSet* _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
	GeeIterator* _email_it;
	FolksIndividual* _tmp8_;
	GeeSet* _tmp9_;
	GeeSet* _tmp10_;
	GeeIterator* _tmp11_;
	GeeIterator* _tmp12_;
	gboolean _tmp13_;
	FolksEmailFieldDetails* email;
	GeeIterator* _tmp14_;
	gpointer _tmp15_;
	FolksEmailFieldDetails* _tmp16_;
	gconstpointer _tmp17_;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
	GeeHashMap* _tmp20_;
	GeeIterator* _proto1_it;
	FolksIndividual* _tmp21_;
	GeeMultiMap* _tmp22_;
	GeeMultiMap* _tmp23_;
	GeeSet* _tmp24_;
	GeeSet* _tmp25_;
	GeeIterator* _tmp26_;
	GeeIterator* _tmp27_;
	GeeIterator* _tmp28_;
	gboolean _tmp29_;
	gchar* proto1;
	GeeIterator* _tmp30_;
	gpointer _tmp31_;
	GeeCollection* im_fds1;
	FolksIndividual* _tmp32_;
	GeeMultiMap* _tmp33_;
	GeeMultiMap* _tmp34_;
	const gchar* _tmp35_;
	GeeCollection* _tmp36_;
	GeeIterator* _im_fd1_it;
	GeeCollection* _tmp37_;
	GeeIterator* _tmp38_;
	GeeIterator* _tmp39_;
	gboolean _tmp40_;
	FolksImFieldDetails* im_fd1;
	GeeIterator* _tmp41_;
	gpointer _tmp42_;
	FolksImFieldDetails* _tmp43_;
	gconstpointer _tmp44_;
	const gchar* _tmp45_;
	const gchar* _tmp46_;
	GeeHashMap* _tmp47_;
	GeeHashMap* _tmp48_;
	gint _tmp49_;
	gint _tmp50_;
	GMainLoop* _tmp51_;
};


static gpointer link_personas_tests_parent_class = NULL;

GType linking_method_get_type (void) G_GNUC_CONST;
GType link_personas_tests_get_type (void) G_GNUC_CONST;
#define LINK_PERSONAS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LINK_PERSONAS_TESTS, LinkPersonasTestsPrivate))
enum  {
	LINK_PERSONAS_TESTS_DUMMY_PROPERTY
};
LinkPersonasTests* link_personas_tests_new (void);
LinkPersonasTests* link_personas_tests_construct (GType object_type);
void link_personas_tests_test_linking_personas_via_im_addresses (LinkPersonasTests* self);
static void _link_personas_tests_test_linking_personas_via_im_addresses_folks_test_case_test_method (gpointer self);
void link_personas_tests_test_linking_personas_via_local_ids (LinkPersonasTests* self);
static void _link_personas_tests_test_linking_personas_via_local_ids_folks_test_case_test_method (gpointer self);
void link_personas_tests_test_linking_personas_via_web_service_addresses (LinkPersonasTests* self);
static void _link_personas_tests_test_linking_personas_via_web_service_addresses_folks_test_case_test_method (gpointer self);
void link_personas_tests_test_linking_via_email_as_im_address (LinkPersonasTests* self);
static void _link_personas_tests_test_linking_via_email_as_im_address_folks_test_case_test_method (gpointer self);
static void link_personas_tests_real_create_backend (EdsTestTestCase* base);
static void _link_personas_tests_test_linking_personas (LinkPersonasTests* self);
static void _link_personas_tests_test_linking_personas_async (LinkPersonasTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_tests_test_linking_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_);
static void _link_personas_tests_test_linking_personas_async_data_free (gpointer _data);
static gboolean _link_personas_tests_test_linking_personas_async_co (LinkPersonasTestsTestLinkingPersonasAsyncData* _data_);
static void _link_personas_tests_test_linking_personas_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _link_personas_tests_individuals_changed_cb (LinkPersonasTests* self, GeeMultiMap* changes);
static void __link_personas_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static FolksPersonaStore* _link_personas_tests_get_store (LinkPersonasTests* self, FolksBackendStore* store, const gchar* store_id);
static void _link_personas_tests_notify_pstore_cb (LinkPersonasTests* self, GObject* _pstore, GParamSpec* ps);
static void __link_personas_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _link_personas_tests_add_personas (LinkPersonasTests* self, FolksPersonaStore* pstore1, FolksPersonaStore* pstore2, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_tests_add_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_);
static void _link_personas_tests_add_personas_data_free (gpointer _data);
static gboolean _link_personas_tests_add_personas_co (LinkPersonasTestsAddPersonasData* _data_);
static void _g_free0_ (gpointer var);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void _link_personas_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _link_personas_tests_individuals_changed_async (LinkPersonasTests* self, GeeMultiMap* changes);
static void _link_personas_tests_check_auto_linked_personas (LinkPersonasTests* self, FolksIndividual* i, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_tests_check_auto_linked_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_);
static void _link_personas_tests_check_personas (LinkPersonasTests* self, FolksIndividual* i, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_tests_check_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_);
static void _link_personas_tests_check_personas_data_free (gpointer _data);
static gboolean _link_personas_tests_check_personas_co (LinkPersonasTestsCheckPersonasData* _data_);
static gboolean ______lambda3_ (LinkPersonasTests* self);
static gboolean _______lambda3__gsource_func (gpointer self);
static void _link_personas_tests_check_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _link_personas_tests_check_auto_linked_personas_data_free (gpointer _data);
static gboolean _link_personas_tests_check_auto_linked_personas_co (LinkPersonasTestsCheckAutoLinkedPersonasData* _data_);
static void link_personas_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


GType linking_method_get_type (void) {
	static volatile gsize linking_method_type_id__volatile = 0;
	if (g_once_init_enter (&linking_method_type_id__volatile)) {
		static const GEnumValue values[] = {{LINKING_METHOD_IM_ADDRESSES, "LINKING_METHOD_IM_ADDRESSES", "im-addresses"}, {LINKING_METHOD_LOCAL_IDS, "LINKING_METHOD_LOCAL_IDS", "local-ids"}, {LINKING_METHOD_WEB_SERVICE_ADDRESSES, "LINKING_METHOD_WEB_SERVICE_ADDRESSES", "web-service-addresses"}, {LINKING_METHOD_EMAIL_AS_IM_ADDRESS, "LINKING_METHOD_EMAIL_AS_IM_ADDRESS", "email-as-im-address"}, {0, NULL, NULL}};
		GType linking_method_type_id;
		linking_method_type_id = g_enum_register_static ("LinkingMethod", values);
		g_once_init_leave (&linking_method_type_id__volatile, linking_method_type_id);
	}
	return linking_method_type_id__volatile;
}


static void _link_personas_tests_test_linking_personas_via_im_addresses_folks_test_case_test_method (gpointer self) {
#line 56 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	link_personas_tests_test_linking_personas_via_im_addresses ((LinkPersonasTests*) self);
#line 613 "link-personas.c"
}


static void _link_personas_tests_test_linking_personas_via_local_ids_folks_test_case_test_method (gpointer self) {
#line 58 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	link_personas_tests_test_linking_personas_via_local_ids ((LinkPersonasTests*) self);
#line 620 "link-personas.c"
}


static void _link_personas_tests_test_linking_personas_via_web_service_addresses_folks_test_case_test_method (gpointer self) {
#line 60 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	link_personas_tests_test_linking_personas_via_web_service_addresses ((LinkPersonasTests*) self);
#line 627 "link-personas.c"
}


static void _link_personas_tests_test_linking_via_email_as_im_address_folks_test_case_test_method (gpointer self) {
#line 62 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	link_personas_tests_test_linking_via_email_as_im_address ((LinkPersonasTests*) self);
#line 634 "link-personas.c"
}


LinkPersonasTests* link_personas_tests_construct (GType object_type) {
	LinkPersonasTests * self = NULL;
#line 54 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self = (LinkPersonasTests*) eds_test_test_case_construct (object_type, "LinkPersonasTests");
#line 56 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test linking personas via IM addresses", _link_personas_tests_test_linking_personas_via_im_addresses_folks_test_case_test_method, self);
#line 58 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test linking personas via local IDs", _link_personas_tests_test_linking_personas_via_local_ids_folks_test_case_test_method, self);
#line 60 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test linking personas via web service addresses", _link_personas_tests_test_linking_personas_via_web_service_addresses_folks_test_case_test_method, self);
#line 62 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test auto linking via e-mail address as IM address", _link_personas_tests_test_linking_via_email_as_im_address_folks_test_case_test_method, self);
#line 52 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return self;
#line 652 "link-personas.c"
}


LinkPersonasTests* link_personas_tests_new (void) {
#line 52 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return link_personas_tests_construct (TYPE_LINK_PERSONAS_TESTS);
#line 659 "link-personas.c"
}


static void link_personas_tests_real_create_backend (EdsTestTestCase* base) {
	LinkPersonasTests * self;
	gint _tmp0_ = 0;
	EdsTestBackend* _tmp1_ = NULL;
	EdsTestBackend* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 66 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self = (LinkPersonasTests*) base;
#line 71 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = self->priv->_test_num;
#line 71 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_test_num = _tmp0_ + 1;
#line 72 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp1_ = eds_test_backend_new ();
#line 72 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_eds_test_backend_unref0 (((EdsTestTestCase*) self)->eds_backend);
#line 72 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	((EdsTestTestCase*) self)->eds_backend = _tmp1_;
#line 73 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp2_ = ((EdsTestTestCase*) self)->eds_backend;
#line 73 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp3_ = self->priv->_test_num;
#line 73 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp4_ = g_strdup_printf ("%i", _tmp3_);
#line 73 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp5_ = _tmp4_;
#line 73 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp6_ = g_strconcat ("test", _tmp5_, NULL);
#line 73 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp7_ = _tmp6_;
#line 73 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	eds_test_backend_set_up (_tmp2_, FALSE, _tmp7_);
#line 73 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (_tmp7_);
#line 73 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (_tmp5_);
#line 703 "link-personas.c"
}


void link_personas_tests_test_linking_personas_via_im_addresses (LinkPersonasTests* self) {
#line 76 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 78 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_linking_method = LINKING_METHOD_IM_ADDRESSES;
#line 79 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_test_linking_personas (self);
#line 714 "link-personas.c"
}


void link_personas_tests_test_linking_personas_via_local_ids (LinkPersonasTests* self) {
#line 82 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 84 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_linking_method = LINKING_METHOD_LOCAL_IDS;
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_test_linking_personas (self);
#line 725 "link-personas.c"
}


void link_personas_tests_test_linking_personas_via_web_service_addresses (LinkPersonasTests* self) {
#line 88 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 90 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_linking_method = LINKING_METHOD_WEB_SERVICE_ADDRESSES;
#line 91 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_test_linking_personas (self);
#line 736 "link-personas.c"
}


void link_personas_tests_test_linking_via_email_as_im_address (LinkPersonasTests* self) {
#line 94 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 96 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_linking_method = LINKING_METHOD_EMAIL_AS_IM_ADDRESS;
#line 97 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_test_linking_personas (self);
#line 747 "link-personas.c"
}


static void _link_personas_tests_test_linking_personas (LinkPersonasTests* self) {
	GMainLoop* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	GeeHashMap* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	LinkingMethod _tmp8_ = 0;
	GMainLoop* _tmp19_ = NULL;
#line 100 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 102 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 102 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 102 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_main_loop = _tmp0_;
#line 103 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp1_ = g_strdup ("persona #1");
#line 103 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 103 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_persona_fullname_1 = _tmp1_;
#line 104 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp2_ = g_strdup ("persona #2");
#line 104 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 104 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_persona_fullname_2 = _tmp2_;
#line 105 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp3_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 105 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (self->priv->_personas);
#line 105 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_personas = _tmp3_;
#line 106 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_persona_found_1 = FALSE;
#line 107 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_persona_found_2 = FALSE;
#line 108 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_linking_fired = FALSE;
#line 109 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp4_ = g_strdup ("");
#line 109 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (self->priv->_persona_iid_1);
#line 109 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_persona_iid_1 = _tmp4_;
#line 110 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp5_ = g_strdup ("");
#line 110 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (self->priv->_persona_iid_2);
#line 110 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_persona_iid_2 = _tmp5_;
#line 112 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp6_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 112 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (self->priv->_linking_props);
#line 112 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_linking_props = _tmp6_;
#line 113 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp8_ = self->priv->_linking_method;
#line 113 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_tmp8_ == LINKING_METHOD_IM_ADDRESSES) {
#line 113 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp7_ = TRUE;
#line 818 "link-personas.c"
	} else {
		LinkingMethod _tmp9_ = 0;
#line 114 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp9_ = self->priv->_linking_method;
#line 114 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp7_ = _tmp9_ == LINKING_METHOD_WEB_SERVICE_ADDRESSES;
#line 825 "link-personas.c"
	}
#line 113 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_tmp7_) {
#line 829 "link-personas.c"
		GeeHashMap* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		GeeHashMap* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp10_ = self->priv->_linking_props;
#line 116 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp11_ = self->priv->_im_address_1;
#line 116 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp10_, "prop1", _tmp11_);
#line 117 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp12_ = self->priv->_linking_props;
#line 117 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp13_ = self->priv->_im_address_2;
#line 117 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp12_, "prop2", _tmp13_);
#line 846 "link-personas.c"
	} else {
		LinkingMethod _tmp14_ = 0;
#line 119 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp14_ = self->priv->_linking_method;
#line 119 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_tmp14_ == LINKING_METHOD_EMAIL_AS_IM_ADDRESS) {
#line 853 "link-personas.c"
			GeeHashMap* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
			GeeHashMap* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp15_ = self->priv->_linking_props;
#line 121 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp16_ = self->priv->_auto_linkable_email;
#line 121 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			gee_abstract_map_set ((GeeAbstractMap*) _tmp15_, "prop1", _tmp16_);
#line 122 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp17_ = self->priv->_linking_props;
#line 122 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp18_ = self->priv->_auto_linkable_email;
#line 122 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			gee_abstract_map_set ((GeeAbstractMap*) _tmp17_, "prop2", _tmp18_);
#line 870 "link-personas.c"
		}
	}
#line 125 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_test_linking_personas_async (self, NULL, NULL);
#line 127 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp19_ = self->priv->_main_loop;
#line 127 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	folks_test_utils_loop_run_with_timeout (_tmp19_, 8);
#line 129 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 129 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_aggregator = NULL;
#line 130 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 130 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_main_loop = NULL;
#line 887 "link-personas.c"
}


static void _link_personas_tests_test_linking_personas_async_data_free (gpointer _data) {
	LinkPersonasTestsTestLinkingPersonasAsyncData* _data_;
	_data_ = _data;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->self);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_slice_free (LinkPersonasTestsTestLinkingPersonasAsyncData, _data_);
#line 898 "link-personas.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return self ? g_object_ref (self) : NULL;
#line 905 "link-personas.c"
}


static void _link_personas_tests_test_linking_personas_async (LinkPersonasTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasTestsTestLinkingPersonasAsyncData* _data_;
	LinkPersonasTests* _tmp0_ = NULL;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_ = g_slice_new0 (LinkPersonasTestsTestLinkingPersonasAsyncData);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_tests_test_linking_personas_async);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_tests_test_linking_personas_async_data_free);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->self = _tmp0_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_test_linking_personas_async_co (_data_);
#line 924 "link-personas.c"
}


static void _link_personas_tests_test_linking_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_) {
	LinkPersonasTestsTestLinkingPersonasAsyncData* _data_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 932 "link-personas.c"
}


static void _link_personas_tests_test_linking_personas_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkPersonasTestsTestLinkingPersonasAsyncData* _data_;
#line 136 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_ = _user_data_;
#line 136 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_source_object_ = source_object;
#line 136 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_res_ = _res_;
#line 136 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_test_linking_personas_async_co (_data_);
#line 946 "link-personas.c"
}


static void __link_personas_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 138 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_individuals_changed_cb ((LinkPersonasTests*) self, changes);
#line 953 "link-personas.c"
}


static void __link_personas_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 148 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_notify_pstore_cb ((LinkPersonasTests*) self, _sender, pspec);
#line 960 "link-personas.c"
}


static gboolean _link_personas_tests_test_linking_personas_async_co (LinkPersonasTestsTestLinkingPersonasAsyncData* _data_) {
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	switch (_data_->_state_) {
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		case 0:
#line 969 "link-personas.c"
		goto _state_0;
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		case 1:
#line 973 "link-personas.c"
		goto _state_1;
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		case 2:
#line 977 "link-personas.c"
		goto _state_2;
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		case 3:
#line 981 "link-personas.c"
		goto _state_3;
		default:
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_assert_not_reached ();
#line 986 "link-personas.c"
	}
	_state_0:
#line 135 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp0_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 135 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->store = _data_->_tmp0_;
#line 136 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_state_ = 1;
#line 136 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	folks_backend_store_prepare (_data_->store, _link_personas_tests_test_linking_personas_async_ready, _data_);
#line 136 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return FALSE;
#line 1001 "link-personas.c"
	_state_1:
#line 136 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 137 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp1_ = NULL;
#line 137 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 137 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 137 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 138 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp2_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 138 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __link_personas_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 1019 "link-personas.c"
	{
#line 142 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp3_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 142 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_state_ = 2;
#line 142 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _link_personas_tests_test_linking_personas_async_ready, _data_);
#line 142 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		return FALSE;
#line 1031 "link-personas.c"
		_state_2:
#line 142 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 142 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1037 "link-personas.c"
			goto __catch0_g_error;
		}
#line 144 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp4_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp4_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 144 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp5_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp5_ = eds_test_backend_get_address_book_uid (_data_->_tmp4_);
#line 144 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp6_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 144 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp7_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp7_ = _link_personas_tests_get_store (_data_->self, _data_->store, _data_->_tmp6_);
#line 144 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->pstore = _data_->_tmp7_;
#line 146 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp8_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp8_ = _data_->pstore;
#line 146 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_vala_assert (_data_->_tmp8_ != NULL, "pstore != null");
#line 148 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp9_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp9_ = _data_->pstore;
#line 148 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_signal_connect_object ((GObject*) _data_->_tmp9_, "notify::is-prepared", (GCallback) __link_personas_tests_notify_pstore_cb_g_object_notify, _data_->self, 0);
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp10_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp10_ = _data_->pstore;
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp11_ = FALSE;
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp11_ = folks_persona_store_get_is_prepared (_data_->_tmp10_);
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp12_ = FALSE;
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp12_ = _data_->_tmp11_;
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_tmp12_) {
#line 150 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp13_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp13_ = _data_->pstore;
#line 150 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp14_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp14_ = _data_->pstore;
#line 150 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_state_ = 3;
#line 150 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_link_personas_tests_add_personas (_data_->self, _data_->_tmp13_, _data_->_tmp14_, _link_personas_tests_test_linking_personas_async_ready, _data_);
#line 150 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			return FALSE;
#line 1098 "link-personas.c"
			_state_3:
#line 150 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_link_personas_tests_add_personas_finish (_data_->self, _data_->_res_);
#line 1102 "link-personas.c"
		}
#line 140 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_object_unref0 (_data_->pstore);
#line 1106 "link-personas.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 140 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->e = _data_->_inner_error_;
#line 140 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_inner_error_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp15_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp15_ = _data_->e;
#line 154 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp16_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp16_ = _data_->_tmp15_->message;
#line 154 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_warning ("link-personas.vala:154: Error when calling prepare: %s\n", _data_->_tmp16_);
#line 140 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_error_free0 (_data_->e);
#line 1127 "link-personas.c"
	}
	__finally0:
#line 140 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_inner_error_ != NULL) {
#line 140 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_object_unref0 (_data_->store);
#line 140 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 140 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_clear_error (&_data_->_inner_error_);
#line 140 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		return FALSE;
#line 1140 "link-personas.c"
	}
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->store);
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_state_ == 0) {
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1148 "link-personas.c"
	} else {
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1152 "link-personas.c"
	}
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_object_unref (_data_->_async_result);
#line 133 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return FALSE;
#line 1158 "link-personas.c"
}


static void _link_personas_tests_notify_pstore_cb (LinkPersonasTests* self, GObject* _pstore, GParamSpec* ps) {
	FolksPersonaStore* pstore = NULL;
	GObject* _tmp0_ = NULL;
	FolksPersonaStore* _tmp1_ = NULL;
#line 158 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 158 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (_pstore != NULL);
#line 158 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (ps != NULL);
#line 160 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = _pstore;
#line 160 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_PERSONA_STORE, FolksPersonaStore));
#line 160 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	pstore = _tmp1_;
#line 161 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_add_personas (self, pstore, pstore, NULL, NULL);
#line 158 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (pstore);
#line 1182 "link-personas.c"
}


static FolksPersonaStore* _link_personas_tests_get_store (LinkPersonasTests* self, FolksBackendStore* store, const gchar* store_id) {
	FolksPersonaStore* result = NULL;
	FolksPersonaStore* pstore = NULL;
#line 164 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 164 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_val_if_fail (store != NULL, NULL);
#line 164 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_val_if_fail (store_id != NULL, NULL);
#line 166 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	pstore = NULL;
#line 1197 "link-personas.c"
	{
		GeeIterator* _backend_it = NULL;
		FolksBackendStore* _tmp0_ = NULL;
		GeeMap* _tmp1_ = NULL;
		GeeMap* _tmp2_ = NULL;
		GeeCollection* _tmp3_ = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeCollection* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
		GeeIterator* _tmp7_ = NULL;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp0_ = store;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp1_ = folks_backend_store_get_enabled_backends (_tmp0_);
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp2_ = _tmp1_;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp3_ = gee_map_get_values (_tmp2_);
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp4_ = _tmp3_;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp5_ = _tmp4_;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp7_ = _tmp6_;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_object_unref0 (_tmp5_);
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_backend_it = _tmp7_;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		while (TRUE) {
#line 1230 "link-personas.c"
			GeeIterator* _tmp8_ = NULL;
			gboolean _tmp9_ = FALSE;
			FolksBackend* backend = NULL;
			GeeIterator* _tmp10_ = NULL;
			gpointer _tmp11_ = NULL;
			FolksBackend* _tmp12_ = NULL;
			GeeMap* _tmp13_ = NULL;
			GeeMap* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			gpointer _tmp16_ = NULL;
			FolksPersonaStore* _tmp17_ = NULL;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp8_ = _backend_it;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp9_ = gee_iterator_next (_tmp8_);
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (!_tmp9_) {
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				break;
#line 1250 "link-personas.c"
			}
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp10_ = _backend_it;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			backend = (FolksBackend*) _tmp11_;
#line 169 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp12_ = backend;
#line 169 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp13_ = folks_backend_get_persona_stores (_tmp12_);
#line 169 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp14_ = _tmp13_;
#line 169 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp15_ = store_id;
#line 169 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp16_ = gee_map_get (_tmp14_, _tmp15_);
#line 169 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (pstore);
#line 169 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			pstore = (FolksPersonaStore*) _tmp16_;
#line 170 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp17_ = pstore;
#line 170 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (_tmp17_ != NULL) {
#line 171 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_g_object_unref0 (backend);
#line 171 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				break;
#line 1280 "link-personas.c"
			}
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (backend);
#line 1284 "link-personas.c"
		}
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_object_unref0 (_backend_it);
#line 1288 "link-personas.c"
	}
#line 173 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	result = pstore;
#line 173 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return result;
#line 1294 "link-personas.c"
}


static void _link_personas_tests_add_personas_data_free (gpointer _data) {
	LinkPersonasTestsAddPersonasData* _data_;
	_data_ = _data;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->pstore1);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->pstore2);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->self);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_slice_free (LinkPersonasTestsAddPersonasData, _data_);
#line 1309 "link-personas.c"
}


static void _link_personas_tests_add_personas (LinkPersonasTests* self, FolksPersonaStore* pstore1, FolksPersonaStore* pstore2, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasTestsAddPersonasData* _data_;
	LinkPersonasTests* _tmp0_ = NULL;
	FolksPersonaStore* _tmp1_ = NULL;
	FolksPersonaStore* _tmp2_ = NULL;
	FolksPersonaStore* _tmp3_ = NULL;
	FolksPersonaStore* _tmp4_ = NULL;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_ = g_slice_new0 (LinkPersonasTestsAddPersonasData);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_tests_add_personas);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_tests_add_personas_data_free);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->self = _tmp0_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp1_ = pstore1;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->pstore1);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->pstore1 = _tmp2_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp3_ = pstore2;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->pstore2);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->pstore2 = _tmp4_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_add_personas_co (_data_);
#line 1348 "link-personas.c"
}


static void _link_personas_tests_add_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_) {
	LinkPersonasTestsAddPersonasData* _data_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1356 "link-personas.c"
}


static void _g_free0_ (gpointer var) {
#line 189 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	var = (g_free (var), NULL);
#line 1363 "link-personas.c"
}


static void _vala_GValue_free (GValue* self) {
#line 189 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_value_unset (self);
#line 189 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_free (self);
#line 1372 "link-personas.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 189 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 1379 "link-personas.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 198 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 1386 "link-personas.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 198 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return self ? _g_value_dup (self) : NULL;
#line 1393 "link-personas.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 199 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return result;
#line 1402 "link-personas.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 199 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return result;
#line 1411 "link-personas.c"
}


static void _link_personas_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkPersonasTestsAddPersonasData* _data_;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_ = _user_data_;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_source_object_ = source_object;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_res_ = _res_;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_add_personas_co (_data_);
#line 1425 "link-personas.c"
}


static gboolean _link_personas_tests_add_personas_co (LinkPersonasTestsAddPersonasData* _data_) {
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	switch (_data_->_state_) {
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		case 0:
#line 1434 "link-personas.c"
		goto _state_0;
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		case 1:
#line 1438 "link-personas.c"
		goto _state_1;
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		case 2:
#line 1442 "link-personas.c"
		goto _state_2;
		default:
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_assert_not_reached ();
#line 1447 "link-personas.c"
	}
	_state_0:
#line 189 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp0_ = NULL;
#line 189 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp0_ = g_str_hash;
#line 189 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp1_ = NULL;
#line 189 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp1_ = g_str_equal;
#line 189 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp2_ = NULL;
#line 189 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 189 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->details1 = _data_->_tmp2_;
#line 192 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp3_ = NULL;
#line 192 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp3_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_WEB_SERVICE_ADDRESSES);
#line 192 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp4_ = NULL;
#line 192 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp4_ = g_strdup (_data_->_tmp3_);
#line 192 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->wsk = _data_->_tmp4_;
#line 195 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp6_ = 0;
#line 195 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp6_ = _data_->self->priv->_linking_method;
#line 195 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_tmp6_ == LINKING_METHOD_IM_ADDRESSES) {
#line 195 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp5_ = TRUE;
#line 1482 "link-personas.c"
	} else {
#line 196 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp7_ = 0;
#line 196 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp7_ = _data_->self->priv->_linking_method;
#line 196 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp5_ = _data_->_tmp7_ == LINKING_METHOD_EMAIL_AS_IM_ADDRESS;
#line 1490 "link-personas.c"
	}
#line 195 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_tmp5_) {
#line 198 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		memset (&_data_->_tmp8_, 0, sizeof (GValue));
#line 198 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_value_init (&_data_->_tmp8_, GEE_TYPE_MULTI_MAP);
#line 198 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		memset (&_data_->_tmp9_, 0, sizeof (GValue));
#line 198 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 198 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp10_ = NULL;
#line 198 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp10_ = __g_value_dup0 (&_data_->_tmp9_);
#line 198 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		__vala_GValue_free0 (_data_->v1);
#line 198 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->v1 = _data_->_tmp10_;
#line 198 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		G_IS_VALUE (&_data_->_tmp9_) ? (g_value_unset (&_data_->_tmp9_), NULL) : NULL;
#line 199 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp11_ = NULL;
#line 199 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp11_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_IM_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 199 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->im_addrs1 = _data_->_tmp11_;
#line 202 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp12_ = 0;
#line 202 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp12_ = _data_->self->priv->_linking_method;
#line 202 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_tmp12_ == LINKING_METHOD_EMAIL_AS_IM_ADDRESS) {
#line 203 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp13_ = NULL;
#line 203 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp13_ = _data_->im_addrs1;
#line 203 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp14_ = NULL;
#line 203 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp14_ = _data_->self->priv->_auto_linkable_email;
#line 203 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp15_ = NULL;
#line 203 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp15_ = folks_im_field_details_new (_data_->_tmp14_, NULL);
#line 203 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp16_ = NULL;
#line 203 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp16_ = _data_->_tmp15_;
#line 203 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			gee_multi_map_set ((GeeMultiMap*) _data_->_tmp13_, "jabber", _data_->_tmp16_);
#line 203 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->_tmp16_);
#line 1544 "link-personas.c"
		} else {
#line 206 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp17_ = NULL;
#line 206 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp17_ = _data_->im_addrs1;
#line 206 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp18_ = NULL;
#line 206 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp18_ = _data_->self->priv->_im_address_1;
#line 206 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp19_ = NULL;
#line 206 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp19_ = folks_im_field_details_new (_data_->_tmp18_, NULL);
#line 206 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp20_ = NULL;
#line 206 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp20_ = _data_->_tmp19_;
#line 206 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			gee_multi_map_set ((GeeMultiMap*) _data_->_tmp17_, "jabber", _data_->_tmp20_);
#line 206 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->_tmp20_);
#line 1566 "link-personas.c"
		}
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp21_ = NULL;
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp21_ = _data_->v1;
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp22_ = NULL;
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp22_ = _data_->im_addrs1;
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_value_set_object (_data_->_tmp21_, (GObject*) _data_->_tmp22_);
#line 208 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp23_ = NULL;
#line 208 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp23_ = _data_->details1;
#line 208 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp24_ = NULL;
#line 208 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp24_ = g_strdup ("im-addresses");
#line 208 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp25_ = NULL;
#line 208 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp25_ = _data_->v1;
#line 208 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->v1 = NULL;
#line 208 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_hash_table_insert (_data_->_tmp23_, _data_->_tmp24_, _data_->_tmp25_);
#line 195 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_object_unref0 (_data_->im_addrs1);
#line 1596 "link-personas.c"
	} else {
#line 210 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp26_ = 0;
#line 210 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp26_ = _data_->self->priv->_linking_method;
#line 210 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_tmp26_ == LINKING_METHOD_WEB_SERVICE_ADDRESSES) {
#line 212 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			memset (&_data_->_tmp27_, 0, sizeof (GValue));
#line 212 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_value_init (&_data_->_tmp27_, GEE_TYPE_MULTI_MAP);
#line 212 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			memset (&_data_->_tmp28_, 0, sizeof (GValue));
#line 212 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp28_ = _data_->_tmp27_;
#line 212 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp29_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp29_ = __g_value_dup0 (&_data_->_tmp28_);
#line 212 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			__vala_GValue_free0 (_data_->v1);
#line 212 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->v1 = _data_->_tmp29_;
#line 212 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			G_IS_VALUE (&_data_->_tmp28_) ? (g_value_unset (&_data_->_tmp28_), NULL) : NULL;
#line 213 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp30_ = NULL;
#line 213 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp30_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_WEB_SERVICE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 213 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->wsa1 = _data_->_tmp30_;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp31_ = NULL;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp31_ = _data_->wsa1;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp32_ = NULL;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp32_ = _data_->self->priv->_im_address_1;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp33_ = NULL;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp33_ = folks_web_service_field_details_new (_data_->_tmp32_, NULL);
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp34_ = NULL;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp34_ = _data_->_tmp33_;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			gee_multi_map_set ((GeeMultiMap*) _data_->_tmp31_, "twitter", _data_->_tmp34_);
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->_tmp34_);
#line 217 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp35_ = NULL;
#line 217 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp35_ = _data_->v1;
#line 217 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp36_ = NULL;
#line 217 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp36_ = _data_->wsa1;
#line 217 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_value_set_object (_data_->_tmp35_, (GObject*) _data_->_tmp36_);
#line 218 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp37_ = NULL;
#line 218 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp37_ = _data_->details1;
#line 218 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp38_ = NULL;
#line 218 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp38_ = _data_->wsk;
#line 218 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp39_ = NULL;
#line 218 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp39_ = g_strdup (_data_->_tmp38_);
#line 218 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp40_ = NULL;
#line 218 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp40_ = _data_->v1;
#line 218 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->v1 = NULL;
#line 218 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_hash_table_insert (_data_->_tmp37_, _data_->_tmp39_, _data_->_tmp40_);
#line 210 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->wsa1);
#line 1680 "link-personas.c"
		}
	}
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	memset (&_data_->_tmp41_, 0, sizeof (GValue));
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_value_init (&_data_->_tmp41_, G_TYPE_STRING);
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	memset (&_data_->_tmp42_, 0, sizeof (GValue));
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp42_ = _data_->_tmp41_;
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp43_ = NULL;
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp43_ = __g_value_dup0 (&_data_->_tmp42_);
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp44_ = NULL;
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp44_ = _data_->_tmp43_;
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	G_IS_VALUE (&_data_->_tmp42_) ? (g_value_unset (&_data_->_tmp42_), NULL) : NULL;
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->v2 = _data_->_tmp44_;
#line 222 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp45_ = NULL;
#line 222 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp45_ = _data_->v2;
#line 222 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp46_ = NULL;
#line 222 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp46_ = _data_->self->priv->_persona_fullname_1;
#line 222 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_value_set_string (_data_->_tmp45_, _data_->_tmp46_);
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp47_ = NULL;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp47_ = _data_->details1;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp48_ = NULL;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp48_ = g_strdup ("full-name");
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp49_ = NULL;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp49_ = _data_->v2;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->v2 = NULL;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_hash_table_insert (_data_->_tmp47_, _data_->_tmp48_, _data_->_tmp49_);
#line 225 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp50_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp50_ = g_str_hash;
#line 225 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp51_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp51_ = g_str_equal;
#line 225 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp52_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp52_ = g_hash_table_new_full (_data_->_tmp50_, _data_->_tmp51_, _g_free0_, __vala_GValue_free0_);
#line 225 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->details2 = _data_->_tmp52_;
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp53_ = 0;
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp53_ = _data_->self->priv->_linking_method;
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_tmp53_ == LINKING_METHOD_IM_ADDRESSES) {
#line 231 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		memset (&_data_->_tmp54_, 0, sizeof (GValue));
#line 231 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_value_init (&_data_->_tmp54_, GEE_TYPE_MULTI_MAP);
#line 231 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		memset (&_data_->_tmp55_, 0, sizeof (GValue));
#line 231 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp55_ = _data_->_tmp54_;
#line 231 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp56_ = NULL;
#line 231 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp56_ = __g_value_dup0 (&_data_->_tmp55_);
#line 231 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		__vala_GValue_free0 (_data_->v3);
#line 231 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->v3 = _data_->_tmp56_;
#line 231 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		G_IS_VALUE (&_data_->_tmp55_) ? (g_value_unset (&_data_->_tmp55_), NULL) : NULL;
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp57_ = NULL;
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp57_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_IM_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->im_addrs2 = _data_->_tmp57_;
#line 235 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp58_ = NULL;
#line 235 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp58_ = _data_->im_addrs2;
#line 235 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp59_ = NULL;
#line 235 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp59_ = _data_->self->priv->_im_address_2;
#line 235 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp60_ = NULL;
#line 235 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp60_ = folks_im_field_details_new (_data_->_tmp59_, NULL);
#line 235 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp61_ = NULL;
#line 235 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp61_ = _data_->_tmp60_;
#line 235 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		gee_multi_map_set ((GeeMultiMap*) _data_->_tmp58_, "yahoo", _data_->_tmp61_);
#line 235 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_object_unref0 (_data_->_tmp61_);
#line 236 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp62_ = NULL;
#line 236 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp62_ = _data_->v3;
#line 236 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp63_ = NULL;
#line 236 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp63_ = _data_->im_addrs2;
#line 236 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_value_set_object (_data_->_tmp62_, (GObject*) _data_->_tmp63_);
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp64_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp64_ = _data_->details2;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp65_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp65_ = g_strdup ("im-addresses");
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp66_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp66_ = _data_->v3;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->v3 = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_hash_table_insert (_data_->_tmp64_, _data_->_tmp65_, _data_->_tmp66_);
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_object_unref0 (_data_->im_addrs2);
#line 1821 "link-personas.c"
	} else {
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp67_ = 0;
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp67_ = _data_->self->priv->_linking_method;
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_tmp67_ == LINKING_METHOD_WEB_SERVICE_ADDRESSES) {
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			memset (&_data_->_tmp68_, 0, sizeof (GValue));
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_value_init (&_data_->_tmp68_, GEE_TYPE_MULTI_MAP);
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			memset (&_data_->_tmp69_, 0, sizeof (GValue));
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp69_ = _data_->_tmp68_;
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp70_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp70_ = __g_value_dup0 (&_data_->_tmp69_);
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			__vala_GValue_free0 (_data_->v3);
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->v3 = _data_->_tmp70_;
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			G_IS_VALUE (&_data_->_tmp69_) ? (g_value_unset (&_data_->_tmp69_), NULL) : NULL;
#line 242 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp71_ = NULL;
#line 242 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp71_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_WEB_SERVICE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 242 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->wsa2 = _data_->_tmp71_;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp72_ = NULL;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp72_ = _data_->wsa2;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp73_ = NULL;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp73_ = _data_->self->priv->_im_address_2;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp74_ = NULL;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp74_ = folks_web_service_field_details_new (_data_->_tmp73_, NULL);
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp75_ = NULL;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp75_ = _data_->_tmp74_;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			gee_multi_map_set ((GeeMultiMap*) _data_->_tmp72_, "lastfm", _data_->_tmp75_);
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->_tmp75_);
#line 246 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp76_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp76_ = _data_->v3;
#line 246 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp77_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp77_ = _data_->wsa2;
#line 246 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_value_set_object (_data_->_tmp76_, (GObject*) _data_->_tmp77_);
#line 247 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp78_ = NULL;
#line 247 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp78_ = _data_->details2;
#line 247 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp79_ = NULL;
#line 247 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp79_ = _data_->wsk;
#line 247 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp80_ = NULL;
#line 247 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp80_ = g_strdup (_data_->_tmp79_);
#line 247 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp81_ = NULL;
#line 247 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp81_ = _data_->v3;
#line 247 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->v3 = NULL;
#line 247 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_hash_table_insert (_data_->_tmp78_, _data_->_tmp80_, _data_->_tmp81_);
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->wsa2);
#line 1905 "link-personas.c"
		} else {
#line 249 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp82_ = 0;
#line 249 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp82_ = _data_->self->priv->_linking_method;
#line 249 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (_data_->_tmp82_ == LINKING_METHOD_EMAIL_AS_IM_ADDRESS) {
#line 251 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				memset (&_data_->_tmp83_, 0, sizeof (GValue));
#line 251 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				g_value_init (&_data_->_tmp83_, GEE_TYPE_SET);
#line 251 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				memset (&_data_->_tmp84_, 0, sizeof (GValue));
#line 251 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp84_ = _data_->_tmp83_;
#line 251 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp85_ = NULL;
#line 251 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp85_ = __g_value_dup0 (&_data_->_tmp84_);
#line 251 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				__vala_GValue_free0 (_data_->v3);
#line 251 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->v3 = _data_->_tmp85_;
#line 251 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				G_IS_VALUE (&_data_->_tmp84_) ? (g_value_unset (&_data_->_tmp84_), NULL) : NULL;
#line 252 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp86_ = NULL;
#line 252 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp86_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 252 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->emails = _data_->_tmp86_;
#line 255 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp87_ = NULL;
#line 255 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp87_ = _data_->self->priv->_auto_linkable_email;
#line 255 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp88_ = NULL;
#line 255 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp88_ = folks_email_field_details_new (_data_->_tmp87_, NULL);
#line 255 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->email_1 = _data_->_tmp88_;
#line 256 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp89_ = NULL;
#line 256 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp89_ = _data_->emails;
#line 256 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp90_ = NULL;
#line 256 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp90_ = _data_->email_1;
#line 256 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp89_, _data_->_tmp90_);
#line 257 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp91_ = NULL;
#line 257 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp91_ = _data_->v3;
#line 257 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp92_ = NULL;
#line 257 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp92_ = _data_->emails;
#line 257 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				g_value_set_object (_data_->_tmp91_, (GObject*) _data_->_tmp92_);
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp93_ = NULL;
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp93_ = _data_->details2;
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp94_ = NULL;
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp94_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_EMAIL_ADDRESSES);
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp95_ = NULL;
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp95_ = g_strdup (_data_->_tmp94_);
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp96_ = NULL;
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp96_ = _data_->v3;
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->v3 = NULL;
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				g_hash_table_insert (_data_->_tmp93_, _data_->_tmp95_, _data_->_tmp96_);
#line 249 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_g_object_unref0 (_data_->email_1);
#line 249 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_g_object_unref0 (_data_->emails);
#line 1991 "link-personas.c"
			}
		}
	}
#line 263 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	memset (&_data_->_tmp97_, 0, sizeof (GValue));
#line 263 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_value_init (&_data_->_tmp97_, G_TYPE_STRING);
#line 263 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	memset (&_data_->_tmp98_, 0, sizeof (GValue));
#line 263 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp98_ = _data_->_tmp97_;
#line 263 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp99_ = NULL;
#line 263 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp99_ = __g_value_dup0 (&_data_->_tmp98_);
#line 263 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp100_ = NULL;
#line 263 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp100_ = _data_->_tmp99_;
#line 263 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	G_IS_VALUE (&_data_->_tmp98_) ? (g_value_unset (&_data_->_tmp98_), NULL) : NULL;
#line 263 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->v4 = _data_->_tmp100_;
#line 264 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp101_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp101_ = _data_->v4;
#line 264 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp102_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp102_ = _data_->self->priv->_persona_fullname_2;
#line 264 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_value_set_string (_data_->_tmp101_, _data_->_tmp102_);
#line 265 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp103_ = NULL;
#line 265 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp103_ = _data_->details2;
#line 265 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp104_ = NULL;
#line 265 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp104_ = g_strdup ("full-name");
#line 265 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp105_ = NULL;
#line 265 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp105_ = _data_->v4;
#line 265 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->v4 = NULL;
#line 265 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_hash_table_insert (_data_->_tmp103_, _data_->_tmp104_, _data_->_tmp105_);
#line 2041 "link-personas.c"
	{
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp106_ = NULL;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp106_ = _data_->self->priv->_aggregator;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp107_ = NULL;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp107_ = _data_->pstore1;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp108_ = NULL;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp108_ = _data_->details1;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_state_ = 1;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp106_, NULL, _data_->_tmp107_, _data_->_tmp108_, _link_personas_tests_add_personas_ready, _data_);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		return FALSE;
#line 2061 "link-personas.c"
		_state_1:
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp109_ = NULL;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp109_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp106_, _data_->_res_, &_data_->_inner_error_);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp110_ = NULL;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp110_ = _data_->_tmp109_;
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_object_unref0 (_data_->_tmp110_);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_inner_error_ != NULL) {
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 2077 "link-personas.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			__vala_GValue_free0 (_data_->v4);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			__vala_GValue_free0 (_data_->v3);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			__vala_GValue_free0 (_data_->v2);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_free0 (_data_->wsk);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			__vala_GValue_free0 (_data_->v1);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_clear_error (&_data_->_inner_error_);
#line 269 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			return FALSE;
#line 2100 "link-personas.c"
		}
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp111_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp111_ = _data_->self->priv->_aggregator;
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp112_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp112_ = _data_->pstore2;
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp113_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp113_ = _data_->details2;
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_state_ = 2;
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp111_, NULL, _data_->_tmp112_, _data_->_tmp113_, _link_personas_tests_add_personas_ready, _data_);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		return FALSE;
#line 2120 "link-personas.c"
		_state_2:
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp114_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp114_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp111_, _data_->_res_, &_data_->_inner_error_);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp115_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp115_ = _data_->_tmp114_;
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_object_unref0 (_data_->_tmp115_);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_inner_error_ != NULL) {
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 2136 "link-personas.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			__vala_GValue_free0 (_data_->v4);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			__vala_GValue_free0 (_data_->v3);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			__vala_GValue_free0 (_data_->v2);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_free0 (_data_->wsk);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			__vala_GValue_free0 (_data_->v1);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_clear_error (&_data_->_inner_error_);
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			return FALSE;
#line 2159 "link-personas.c"
		}
	}
	goto __finally1;
	__catch1_folks_individual_aggregator_error:
	{
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->e = _data_->_inner_error_;
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_inner_error_ = NULL;
#line 277 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp116_ = NULL;
#line 277 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp116_ = _data_->e;
#line 277 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp117_ = NULL;
#line 277 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp117_ = _data_->_tmp116_->message;
#line 277 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_warning ("link-personas.vala:277: [AddPersonaError] add_persona_from_details: %s" \
"\n", _data_->_tmp117_);
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_error_free0 (_data_->e);
#line 2181 "link-personas.c"
	}
	__finally1:
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_inner_error_ != NULL) {
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		__vala_GValue_free0 (_data_->v4);
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		__vala_GValue_free0 (_data_->v3);
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_hash_table_unref0 (_data_->details2);
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		__vala_GValue_free0 (_data_->v2);
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_free0 (_data_->wsk);
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		__vala_GValue_free0 (_data_->v1);
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_hash_table_unref0 (_data_->details1);
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_clear_error (&_data_->_inner_error_);
#line 267 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		return FALSE;
#line 2206 "link-personas.c"
	}
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	__vala_GValue_free0 (_data_->v4);
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	__vala_GValue_free0 (_data_->v3);
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_hash_table_unref0 (_data_->details2);
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	__vala_GValue_free0 (_data_->v2);
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (_data_->wsk);
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	__vala_GValue_free0 (_data_->v1);
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_hash_table_unref0 (_data_->details1);
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_state_ == 0) {
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2226 "link-personas.c"
	} else {
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2230 "link-personas.c"
	}
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_object_unref (_data_->_async_result);
#line 187 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return FALSE;
#line 2236 "link-personas.c"
}


static void _link_personas_tests_individuals_changed_cb (LinkPersonasTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_ = NULL;
#line 282 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 282 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (changes != NULL);
#line 285 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = changes;
#line 285 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_individuals_changed_async (self, _tmp0_);
#line 2250 "link-personas.c"
}


static void _link_personas_tests_individuals_changed_async (LinkPersonasTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
#line 288 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (self != NULL);
#line 288 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_return_if_fail (changes != NULL);
#line 291 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = changes;
#line 291 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 291 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	added = _tmp1_;
#line 2268 "link-personas.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp2_ = added;
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_i_it = _tmp3_;
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		while (TRUE) {
#line 2281 "link-personas.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksIndividual* _tmp8_ = NULL;
			LinkingMethod _tmp9_ = 0;
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp4_ = _i_it;
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (!_tmp5_) {
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				break;
#line 2297 "link-personas.c"
			}
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp6_ = _i_it;
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			i = (FolksIndividual*) _tmp7_;
#line 295 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp8_ = i;
#line 295 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (_tmp8_ == NULL) {
#line 297 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_g_object_unref0 (i);
#line 297 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				continue;
#line 2313 "link-personas.c"
			}
#line 300 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_tmp9_ = self->priv->_linking_method;
#line 300 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (_tmp9_ == LINKING_METHOD_EMAIL_AS_IM_ADDRESS) {
#line 2319 "link-personas.c"
				FolksIndividual* _tmp10_ = NULL;
#line 301 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_tmp10_ = i;
#line 301 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_link_personas_tests_check_auto_linked_personas (self, _tmp10_, NULL, NULL);
#line 2325 "link-personas.c"
			} else {
				FolksIndividual* _tmp11_ = NULL;
#line 303 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_tmp11_ = i;
#line 303 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_link_personas_tests_check_personas (self, _tmp11_, NULL, NULL);
#line 2332 "link-personas.c"
			}
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (i);
#line 2336 "link-personas.c"
		}
#line 293 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_object_unref0 (_i_it);
#line 2340 "link-personas.c"
	}
#line 288 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (added);
#line 2344 "link-personas.c"
}


static void _link_personas_tests_check_personas_data_free (gpointer _data) {
	LinkPersonasTestsCheckPersonasData* _data_;
	_data_ = _data;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->i);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->self);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_slice_free (LinkPersonasTestsCheckPersonasData, _data_);
#line 2357 "link-personas.c"
}


static void _link_personas_tests_check_personas (LinkPersonasTests* self, FolksIndividual* i, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasTestsCheckPersonasData* _data_;
	LinkPersonasTests* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_ = g_slice_new0 (LinkPersonasTestsCheckPersonasData);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_tests_check_personas);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_tests_check_personas_data_free);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->self = _tmp0_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp1_ = i;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->i);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->i = _tmp2_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_check_personas_co (_data_);
#line 2386 "link-personas.c"
}


static void _link_personas_tests_check_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_) {
	LinkPersonasTestsCheckPersonasData* _data_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2394 "link-personas.c"
}


static gboolean ______lambda3_ (LinkPersonasTests* self) {
	gboolean result = FALSE;
	GMainLoop* _tmp0_ = NULL;
#line 418 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = self->priv->_main_loop;
#line 418 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_main_loop_quit (_tmp0_);
#line 419 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	result = FALSE;
#line 419 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return result;
#line 2409 "link-personas.c"
}


static gboolean _______lambda3__gsource_func (gpointer self) {
	gboolean result;
	result = ______lambda3_ ((LinkPersonasTests*) self);
#line 416 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return result;
#line 2418 "link-personas.c"
}


static void _link_personas_tests_check_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkPersonasTestsCheckPersonasData* _data_;
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_ = _user_data_;
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_source_object_ = source_object;
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_res_ = _res_;
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_check_personas_co (_data_);
#line 2432 "link-personas.c"
}


static gboolean _link_personas_tests_check_personas_co (LinkPersonasTestsCheckPersonasData* _data_) {
#line 317 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	switch (_data_->_state_) {
#line 317 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		case 0:
#line 2441 "link-personas.c"
		goto _state_0;
#line 317 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		case 1:
#line 2445 "link-personas.c"
		goto _state_1;
		default:
#line 317 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_assert_not_reached ();
#line 2450 "link-personas.c"
	}
	_state_0:
#line 319 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp1_ = NULL;
#line 319 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp1_ = _data_->self->priv->_linking_props;
#line 319 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp2_ = 0;
#line 319 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp2_ = gee_abstract_map_get_size ((GeeMap*) _data_->_tmp1_);
#line 319 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp3_ = 0;
#line 319 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 319 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_tmp3_ == 0) {
#line 320 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp4_ = FALSE;
#line 320 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp4_ = _data_->self->priv->_linking_fired;
#line 320 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp0_ = _data_->_tmp4_;
#line 2473 "link-personas.c"
	} else {
#line 319 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp0_ = FALSE;
#line 2477 "link-personas.c"
	}
#line 319 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_tmp0_) {
#line 323 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_state_ == 0) {
#line 323 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2485 "link-personas.c"
		} else {
#line 323 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2489 "link-personas.c"
		}
#line 323 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_object_unref (_data_->_async_result);
#line 323 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		return FALSE;
#line 2495 "link-personas.c"
	}
#line 326 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->first_persona = NULL;
#line 2499 "link-personas.c"
	{
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp5_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp5_ = _data_->i;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp6_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp6_ = folks_individual_get_personas (_data_->_tmp5_);
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp7_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp8_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp8_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp7_);
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_p_it = _data_->_tmp8_;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		while (TRUE) {
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp9_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp9_ = _data_->_p_it;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp10_ = FALSE;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp10_ = gee_iterator_next (_data_->_tmp9_);
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (!_data_->_tmp10_) {
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				break;
#line 2533 "link-personas.c"
			}
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp11_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp11_ = _data_->_p_it;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp12_ = NULL;
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp12_ = gee_iterator_get (_data_->_tmp11_);
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->p = (FolksPersona*) _data_->_tmp12_;
#line 329 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp13_ = NULL;
#line 329 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp13_ = _data_->p;
#line 329 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp14_ = NULL;
#line 329 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp14_ = _g_object_ref0 (_data_->_tmp13_);
#line 329 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->first_persona);
#line 329 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->first_persona = _data_->_tmp14_;
#line 330 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->p);
#line 330 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			break;
#line 2561 "link-personas.c"
		}
#line 327 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_object_unref0 (_data_->_p_it);
#line 2565 "link-personas.c"
	}
#line 333 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp16_ = NULL;
#line 333 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp16_ = _data_->i;
#line 333 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp17_ = NULL;
#line 333 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp17_ = folks_name_details_get_full_name ((FolksNameDetails*) _data_->_tmp16_);
#line 333 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp18_ = NULL;
#line 333 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp18_ = _data_->_tmp17_;
#line 333 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp19_ = NULL;
#line 333 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp19_ = _data_->self->priv->_persona_fullname_1;
#line 333 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (g_strcmp0 (_data_->_tmp18_, _data_->_tmp19_) == 0) {
#line 334 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp20_ = NULL;
#line 334 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp20_ = _data_->self->priv->_persona_iid_1;
#line 334 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp15_ = g_strcmp0 (_data_->_tmp20_, "") == 0;
#line 2591 "link-personas.c"
	} else {
#line 333 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp15_ = FALSE;
#line 2595 "link-personas.c"
	}
#line 333 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_tmp15_) {
#line 336 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp21_ = NULL;
#line 336 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp21_ = _data_->first_persona;
#line 336 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp22_ = NULL;
#line 336 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp22_ = folks_persona_get_iid (_data_->_tmp21_);
#line 336 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp23_ = NULL;
#line 336 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp23_ = _data_->_tmp22_;
#line 336 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp24_ = NULL;
#line 336 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp24_ = g_strdup (_data_->_tmp23_);
#line 336 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_g_free0 (_data_->self->priv->_persona_iid_1);
#line 336 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->self->priv->_persona_iid_1 = _data_->_tmp24_;
#line 337 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp25_ = NULL;
#line 337 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp25_ = _data_->self->priv->_personas;
#line 337 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp26_ = NULL;
#line 337 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp26_ = _data_->first_persona;
#line 337 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp25_, _data_->_tmp26_);
#line 338 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp27_ = 0;
#line 338 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp27_ = _data_->self->priv->_linking_method;
#line 338 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_tmp27_ == LINKING_METHOD_LOCAL_IDS) {
#line 340 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp28_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp28_ = _data_->first_persona;
#line 340 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp29_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp29_ = folks_persona_get_iid ((FolksPersona*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp28_, EDSF_TYPE_PERSONA, EdsfPersona));
#line 340 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp30_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp30_ = _data_->_tmp29_;
#line 340 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp31_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp31_ = g_strdup (_data_->_tmp30_);
#line 340 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->contact_id1 = _data_->_tmp31_;
#line 341 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp32_ = NULL;
#line 341 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp32_ = _data_->self->priv->_linking_props;
#line 341 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp33_ = NULL;
#line 341 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp33_ = _data_->contact_id1;
#line 341 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp32_, "prop1", _data_->_tmp33_);
#line 338 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_free0 (_data_->contact_id1);
#line 2665 "link-personas.c"
		}
	} else {
#line 344 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp35_ = NULL;
#line 344 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp35_ = _data_->i;
#line 344 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp36_ = NULL;
#line 344 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp36_ = folks_name_details_get_full_name ((FolksNameDetails*) _data_->_tmp35_);
#line 344 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp37_ = NULL;
#line 344 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp37_ = _data_->_tmp36_;
#line 344 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp38_ = NULL;
#line 344 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp38_ = _data_->self->priv->_persona_fullname_2;
#line 344 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (g_strcmp0 (_data_->_tmp37_, _data_->_tmp38_) == 0) {
#line 345 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp39_ = NULL;
#line 345 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp39_ = _data_->self->priv->_persona_iid_2;
#line 345 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp34_ = g_strcmp0 (_data_->_tmp39_, "") == 0;
#line 2692 "link-personas.c"
		} else {
#line 344 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp34_ = FALSE;
#line 2696 "link-personas.c"
		}
#line 344 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_tmp34_) {
#line 347 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp40_ = NULL;
#line 347 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp40_ = _data_->first_persona;
#line 347 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp41_ = NULL;
#line 347 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp41_ = folks_persona_get_iid (_data_->_tmp40_);
#line 347 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp42_ = NULL;
#line 347 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp42_ = _data_->_tmp41_;
#line 347 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp43_ = NULL;
#line 347 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp43_ = g_strdup (_data_->_tmp42_);
#line 347 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_free0 (_data_->self->priv->_persona_iid_2);
#line 347 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->self->priv->_persona_iid_2 = _data_->_tmp43_;
#line 348 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp44_ = NULL;
#line 348 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp44_ = _data_->self->priv->_personas;
#line 348 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp45_ = NULL;
#line 348 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp45_ = _data_->first_persona;
#line 348 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp44_, _data_->_tmp45_);
#line 349 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp46_ = 0;
#line 349 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp46_ = _data_->self->priv->_linking_method;
#line 349 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (_data_->_tmp46_ == LINKING_METHOD_LOCAL_IDS) {
#line 351 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp47_ = NULL;
#line 351 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp47_ = _data_->first_persona;
#line 351 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp48_ = NULL;
#line 351 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp48_ = folks_persona_get_iid ((FolksPersona*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp47_, EDSF_TYPE_PERSONA, EdsfPersona));
#line 351 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp49_ = NULL;
#line 351 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp49_ = _data_->_tmp48_;
#line 351 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp50_ = NULL;
#line 351 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp50_ = g_strdup (_data_->_tmp49_);
#line 351 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->contact_id2 = _data_->_tmp50_;
#line 352 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp51_ = NULL;
#line 352 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp51_ = _data_->self->priv->_linking_props;
#line 352 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp52_ = NULL;
#line 352 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp52_ = _data_->contact_id2;
#line 352 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp51_, "prop2", _data_->_tmp52_);
#line 349 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_g_free0 (_data_->contact_id2);
#line 2766 "link-personas.c"
			}
		} else {
#line 355 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp53_ = NULL;
#line 355 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp53_ = _data_->i;
#line 355 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp54_ = NULL;
#line 355 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp54_ = folks_individual_get_personas (_data_->_tmp53_);
#line 355 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp55_ = NULL;
#line 355 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp55_ = _data_->_tmp54_;
#line 355 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp56_ = 0;
#line 355 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp56_ = gee_collection_get_size ((GeeCollection*) _data_->_tmp55_);
#line 355 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp57_ = 0;
#line 355 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp57_ = _data_->_tmp56_;
#line 355 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (_data_->_tmp57_ > 1) {
#line 358 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp58_ = 0;
#line 358 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp58_ = _data_->self->priv->_linking_method;
#line 358 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				if (_data_->_tmp58_ == LINKING_METHOD_IM_ADDRESSES) {
#line 2797 "link-personas.c"
					{
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp59_ = NULL;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp59_ = _data_->i;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp60_ = NULL;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp60_ = folks_im_details_get_im_addresses ((FolksImDetails*) _data_->_tmp59_);
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp61_ = NULL;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp61_ = _data_->_tmp60_;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp62_ = NULL;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp62_ = gee_multi_map_get_keys (_data_->_tmp61_);
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp63_ = NULL;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp63_ = _data_->_tmp62_;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp64_ = NULL;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp64_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp63_);
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp65_ = NULL;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp65_ = _data_->_tmp64_;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_g_object_unref0 (_data_->_tmp63_);
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_proto_it = _data_->_tmp65_;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						while (TRUE) {
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp66_ = NULL;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp66_ = _data_->_proto_it;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp67_ = FALSE;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp67_ = gee_iterator_next (_data_->_tmp66_);
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							if (!_data_->_tmp67_) {
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								break;
#line 2845 "link-personas.c"
							}
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp68_ = NULL;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp68_ = _data_->_proto_it;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp69_ = NULL;
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp69_ = gee_iterator_get (_data_->_tmp68_);
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->proto = (gchar*) _data_->_tmp69_;
#line 362 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp70_ = NULL;
#line 362 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp70_ = _data_->i;
#line 362 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp71_ = NULL;
#line 362 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp71_ = folks_im_details_get_im_addresses ((FolksImDetails*) _data_->_tmp70_);
#line 362 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp72_ = NULL;
#line 362 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp72_ = _data_->_tmp71_;
#line 362 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp73_ = NULL;
#line 362 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp73_ = _data_->proto;
#line 362 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp74_ = NULL;
#line 362 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp74_ = gee_multi_map_get (_data_->_tmp72_, _data_->_tmp73_);
#line 362 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->im_fds = _data_->_tmp74_;
#line 2879 "link-personas.c"
							{
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp75_ = NULL;
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp75_ = _data_->im_fds;
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp76_ = NULL;
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp76_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp75_);
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_im_fd_it = _data_->_tmp76_;
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								while (TRUE) {
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp77_ = NULL;
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp77_ = _data_->_im_fd_it;
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp78_ = FALSE;
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp78_ = gee_iterator_next (_data_->_tmp77_);
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									if (!_data_->_tmp78_) {
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										break;
#line 2905 "link-personas.c"
									}
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp79_ = NULL;
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp79_ = _data_->_im_fd_it;
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp80_ = NULL;
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp80_ = gee_iterator_get (_data_->_tmp79_);
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->im_fd = (FolksImFieldDetails*) _data_->_tmp80_;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp81_ = NULL;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp81_ = _data_->im_fd;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp82_ = NULL;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp82_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _data_->_tmp81_);
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp83_ = NULL;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp83_ = _data_->_tmp82_;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp84_ = NULL;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp84_ = _data_->self->priv->_linking_props;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp85_ = NULL;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp85_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp84_, "prop1");
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp86_ = NULL;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp86_ = (gchar*) _data_->_tmp85_;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp87_ = FALSE;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp87_ = g_strcmp0 ((const gchar*) _data_->_tmp83_, _data_->_tmp86_) == 0;
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_g_free0 (_data_->_tmp86_);
#line 365 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									if (_data_->_tmp87_) {
#line 367 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp88_ = NULL;
#line 367 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp88_ = _data_->self->priv->_linking_props;
#line 367 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp88_, "prop1", NULL);
#line 2955 "link-personas.c"
									} else {
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp89_ = NULL;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp89_ = _data_->im_fd;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp90_ = NULL;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp90_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _data_->_tmp89_);
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp91_ = NULL;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp91_ = _data_->_tmp90_;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp92_ = NULL;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp92_ = _data_->self->priv->_linking_props;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp93_ = NULL;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp93_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp92_, "prop2");
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp94_ = NULL;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp94_ = (gchar*) _data_->_tmp93_;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp95_ = FALSE;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp95_ = g_strcmp0 ((const gchar*) _data_->_tmp91_, _data_->_tmp94_) == 0;
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_g_free0 (_data_->_tmp94_);
#line 369 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										if (_data_->_tmp95_) {
#line 371 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp96_ = NULL;
#line 371 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp96_ = _data_->self->priv->_linking_props;
#line 371 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp96_, "prop2", NULL);
#line 2995 "link-personas.c"
										}
									}
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_g_object_unref0 (_data_->im_fd);
#line 3000 "link-personas.c"
								}
#line 363 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_g_object_unref0 (_data_->_im_fd_it);
#line 3004 "link-personas.c"
							}
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_g_object_unref0 (_data_->im_fds);
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_g_free0 (_data_->proto);
#line 3010 "link-personas.c"
						}
#line 360 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_g_object_unref0 (_data_->_proto_it);
#line 3014 "link-personas.c"
					}
				} else {
#line 376 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					_data_->_tmp97_ = 0;
#line 376 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					_data_->_tmp97_ = _data_->self->priv->_linking_method;
#line 376 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					if (_data_->_tmp97_ == LINKING_METHOD_LOCAL_IDS) {
#line 3023 "link-personas.c"
						{
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp98_ = NULL;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp98_ = _data_->i;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp99_ = NULL;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp99_ = folks_local_id_details_get_local_ids ((FolksLocalIdDetails*) _data_->_tmp98_);
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp100_ = NULL;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp100_ = _data_->_tmp99_;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp101_ = NULL;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp101_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp100_);
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_local_id_it = _data_->_tmp101_;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							while (TRUE) {
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp102_ = NULL;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp102_ = _data_->_local_id_it;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp103_ = FALSE;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp103_ = gee_iterator_next (_data_->_tmp102_);
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								if (!_data_->_tmp103_) {
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									break;
#line 3057 "link-personas.c"
								}
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp104_ = NULL;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp104_ = _data_->_local_id_it;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp105_ = NULL;
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp105_ = gee_iterator_get (_data_->_tmp104_);
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->local_id = (gchar*) _data_->_tmp105_;
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp106_ = NULL;
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp106_ = _data_->local_id;
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp107_ = NULL;
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp107_ = _data_->self->priv->_linking_props;
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp108_ = NULL;
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp108_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp107_, "prop1");
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp109_ = NULL;
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp109_ = (gchar*) _data_->_tmp108_;
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp110_ = FALSE;
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp110_ = g_strcmp0 (_data_->_tmp106_, _data_->_tmp109_) == 0;
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_g_free0 (_data_->_tmp109_);
#line 380 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								if (_data_->_tmp110_) {
#line 382 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp111_ = NULL;
#line 382 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp111_ = _data_->self->priv->_linking_props;
#line 382 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp111_, "prop1", NULL);
#line 3099 "link-personas.c"
								} else {
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp112_ = NULL;
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp112_ = _data_->local_id;
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp113_ = NULL;
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp113_ = _data_->self->priv->_linking_props;
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp114_ = NULL;
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp114_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp113_, "prop2");
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp115_ = NULL;
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp115_ = (gchar*) _data_->_tmp114_;
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp116_ = FALSE;
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp116_ = g_strcmp0 (_data_->_tmp112_, _data_->_tmp115_) == 0;
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_g_free0 (_data_->_tmp115_);
#line 384 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									if (_data_->_tmp116_) {
#line 386 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp117_ = NULL;
#line 386 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp117_ = _data_->self->priv->_linking_props;
#line 386 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp117_, "prop2", NULL);
#line 3131 "link-personas.c"
									}
								}
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_g_free0 (_data_->local_id);
#line 3136 "link-personas.c"
							}
#line 378 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_g_object_unref0 (_data_->_local_id_it);
#line 3140 "link-personas.c"
						}
					} else {
#line 390 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp118_ = 0;
#line 390 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp118_ = _data_->self->priv->_linking_method;
#line 390 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						if (_data_->_tmp118_ == LINKING_METHOD_WEB_SERVICE_ADDRESSES) {
#line 3149 "link-personas.c"
							{
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp119_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp119_ = _data_->i;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp120_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp120_ = folks_web_service_details_get_web_service_addresses ((FolksWebServiceDetails*) _data_->_tmp119_);
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp121_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp121_ = _data_->_tmp120_;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp122_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp122_ = gee_multi_map_get_keys (_data_->_tmp121_);
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp123_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp123_ = _data_->_tmp122_;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp124_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp124_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp123_);
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp125_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_tmp125_ = _data_->_tmp124_;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_g_object_unref0 (_data_->_tmp123_);
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_data_->_service_it = _data_->_tmp125_;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								while (TRUE) {
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp126_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp126_ = _data_->_service_it;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp127_ = FALSE;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp127_ = gee_iterator_next (_data_->_tmp126_);
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									if (!_data_->_tmp127_) {
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										break;
#line 3197 "link-personas.c"
									}
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp128_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp128_ = _data_->_service_it;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp129_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp129_ = gee_iterator_get (_data_->_tmp128_);
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->service = (gchar*) _data_->_tmp129_;
#line 394 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp130_ = NULL;
#line 394 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp130_ = _data_->i;
#line 394 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp131_ = NULL;
#line 394 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp131_ = folks_web_service_details_get_web_service_addresses ((FolksWebServiceDetails*) _data_->_tmp130_);
#line 394 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp132_ = NULL;
#line 394 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp132_ = _data_->_tmp131_;
#line 394 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp133_ = NULL;
#line 394 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp133_ = _data_->service;
#line 394 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp134_ = NULL;
#line 394 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->_tmp134_ = gee_multi_map_get (_data_->_tmp132_, _data_->_tmp133_);
#line 394 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_data_->ws_fds = _data_->_tmp134_;
#line 3231 "link-personas.c"
									{
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp135_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp135_ = _data_->ws_fds;
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp136_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_tmp136_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp135_);
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_data_->_ws_fd_it = _data_->_tmp136_;
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										while (TRUE) {
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp137_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp137_ = _data_->_ws_fd_it;
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp138_ = FALSE;
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp138_ = gee_iterator_next (_data_->_tmp137_);
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											if (!_data_->_tmp138_) {
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												break;
#line 3257 "link-personas.c"
											}
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp139_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp139_ = _data_->_ws_fd_it;
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp140_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp140_ = gee_iterator_get (_data_->_tmp139_);
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->ws_fd = (FolksWebServiceFieldDetails*) _data_->_tmp140_;
#line 397 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp141_ = NULL;
#line 397 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp141_ = _data_->self->priv->_linking_props;
#line 397 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp142_ = NULL;
#line 397 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp142_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp141_, "prop1");
#line 397 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->prop1 = (gchar*) _data_->_tmp142_;
#line 398 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp143_ = NULL;
#line 398 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp143_ = _data_->self->priv->_linking_props;
#line 398 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp144_ = NULL;
#line 398 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp144_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp143_, "prop2");
#line 398 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->prop2 = (gchar*) _data_->_tmp144_;
#line 399 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp146_ = NULL;
#line 399 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_data_->_tmp146_ = _data_->prop1;
#line 399 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											if (_data_->_tmp146_ != NULL) {
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp147_ = NULL;
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp147_ = _data_->ws_fd;
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp148_ = NULL;
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp148_ = _data_->prop1;
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp149_ = NULL;
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp149_ = folks_web_service_field_details_new (_data_->_tmp148_, NULL);
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp150_ = NULL;
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp150_ = _data_->_tmp149_;
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp151_ = FALSE;
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp151_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _data_->_tmp147_, (FolksAbstractFieldDetails*) _data_->_tmp150_);
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp145_ = _data_->_tmp151_;
#line 400 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_g_object_unref0 (_data_->_tmp150_);
#line 3319 "link-personas.c"
											} else {
#line 399 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp145_ = FALSE;
#line 3323 "link-personas.c"
											}
#line 399 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											if (_data_->_tmp145_) {
#line 402 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp152_ = NULL;
#line 402 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp152_ = _data_->self->priv->_linking_props;
#line 402 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp152_, "prop1", NULL);
#line 3333 "link-personas.c"
											} else {
#line 404 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp154_ = NULL;
#line 404 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												_data_->_tmp154_ = _data_->prop2;
#line 404 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												if (_data_->_tmp154_ != NULL) {
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp155_ = NULL;
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp155_ = _data_->ws_fd;
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp156_ = NULL;
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp156_ = _data_->prop2;
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp157_ = NULL;
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp157_ = folks_web_service_field_details_new (_data_->_tmp156_, NULL);
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp158_ = NULL;
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp158_ = _data_->_tmp157_;
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp159_ = FALSE;
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp159_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _data_->_tmp155_, (FolksAbstractFieldDetails*) _data_->_tmp158_);
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp153_ = _data_->_tmp159_;
#line 405 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_g_object_unref0 (_data_->_tmp158_);
#line 3365 "link-personas.c"
												} else {
#line 404 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp153_ = FALSE;
#line 3369 "link-personas.c"
												}
#line 404 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
												if (_data_->_tmp153_) {
#line 407 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp160_ = NULL;
#line 407 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													_data_->_tmp160_ = _data_->self->priv->_linking_props;
#line 407 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
													gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp160_, "prop2", NULL);
#line 3379 "link-personas.c"
												}
											}
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_g_free0 (_data_->prop2);
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_g_free0 (_data_->prop1);
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
											_g_object_unref0 (_data_->ws_fd);
#line 3388 "link-personas.c"
										}
#line 395 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
										_g_object_unref0 (_data_->_ws_fd_it);
#line 3392 "link-personas.c"
									}
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_g_object_unref0 (_data_->ws_fds);
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
									_g_free0 (_data_->service);
#line 3398 "link-personas.c"
								}
#line 392 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
								_g_object_unref0 (_data_->_service_it);
#line 3402 "link-personas.c"
							}
						}
					}
				}
#line 413 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp161_ = NULL;
#line 413 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp161_ = _data_->self->priv->_linking_props;
#line 413 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp162_ = 0;
#line 413 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp162_ = gee_abstract_map_get_size ((GeeMap*) _data_->_tmp161_);
#line 413 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp163_ = 0;
#line 413 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp163_ = _data_->_tmp162_;
#line 413 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				if (_data_->_tmp163_ == 0) {
#line 416 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 5, _______lambda3__gsource_func, g_object_ref (_data_->self), g_object_unref);
#line 3423 "link-personas.c"
				}
			}
		}
	}
#line 426 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp165_ = NULL;
#line 426 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp165_ = _data_->self->priv->_personas;
#line 426 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp166_ = 0;
#line 426 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp166_ = gee_abstract_collection_get_size ((GeeCollection*) _data_->_tmp165_);
#line 426 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp167_ = 0;
#line 426 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp167_ = _data_->_tmp166_;
#line 426 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_tmp167_ == 2) {
#line 427 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp168_ = FALSE;
#line 427 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp168_ = _data_->self->priv->_linking_fired;
#line 427 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp164_ = _data_->_tmp168_ == FALSE;
#line 3448 "link-personas.c"
	} else {
#line 426 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp164_ = FALSE;
#line 3452 "link-personas.c"
	}
#line 426 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_tmp164_) {
#line 429 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->self->priv->_linking_fired = TRUE;
#line 3458 "link-personas.c"
		{
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp169_ = NULL;
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp169_ = _data_->self->priv->_aggregator;
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp170_ = NULL;
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp170_ = _data_->self->priv->_personas;
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_state_ = 1;
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			folks_individual_aggregator_link_personas (_data_->_tmp169_, (GeeSet*) _data_->_tmp170_, _link_personas_tests_check_personas_ready, _data_);
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			return FALSE;
#line 3474 "link-personas.c"
			_state_1:
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			folks_individual_aggregator_link_personas_finish (_data_->_tmp169_, _data_->_res_, &_data_->_inner_error_);
#line 432 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			if (_data_->_inner_error_ != NULL) {
#line 3480 "link-personas.c"
				goto __catch2_g_error;
			}
		}
		goto __finally2;
		__catch2_g_error:
		{
#line 430 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->e = _data_->_inner_error_;
#line 430 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_inner_error_ = NULL;
#line 436 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp171_ = NULL;
#line 436 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp171_ = _data_->e;
#line 436 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp172_ = NULL;
#line 436 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp172_ = _data_->_tmp171_->message;
#line 436 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_warning ("link-personas.vala:436: link_personas: %s\n", _data_->_tmp172_);
#line 430 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_error_free0 (_data_->e);
#line 3503 "link-personas.c"
		}
		__finally2:
#line 430 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_inner_error_ != NULL) {
#line 430 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->first_persona);
#line 430 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 430 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_clear_error (&_data_->_inner_error_);
#line 430 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			return FALSE;
#line 3516 "link-personas.c"
		}
	}
#line 317 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->first_persona);
#line 317 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_state_ == 0) {
#line 317 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3525 "link-personas.c"
	} else {
#line 317 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3529 "link-personas.c"
	}
#line 317 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_object_unref (_data_->_async_result);
#line 317 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return FALSE;
#line 3535 "link-personas.c"
}


static void _link_personas_tests_check_auto_linked_personas_data_free (gpointer _data) {
	LinkPersonasTestsCheckAutoLinkedPersonasData* _data_;
	_data_ = _data;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->i);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->self);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_slice_free (LinkPersonasTestsCheckAutoLinkedPersonasData, _data_);
#line 3548 "link-personas.c"
}


static void _link_personas_tests_check_auto_linked_personas (LinkPersonasTests* self, FolksIndividual* i, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasTestsCheckAutoLinkedPersonasData* _data_;
	LinkPersonasTests* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_ = g_slice_new0 (LinkPersonasTestsCheckAutoLinkedPersonasData);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_tests_check_auto_linked_personas);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_tests_check_auto_linked_personas_data_free);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->self = _tmp0_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp1_ = i;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (_data_->i);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->i = _tmp2_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_link_personas_tests_check_auto_linked_personas_co (_data_);
#line 3577 "link-personas.c"
}


static void _link_personas_tests_check_auto_linked_personas_finish (LinkPersonasTests* self, GAsyncResult* _res_) {
	LinkPersonasTestsCheckAutoLinkedPersonasData* _data_;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3585 "link-personas.c"
}


static gboolean _link_personas_tests_check_auto_linked_personas_co (LinkPersonasTestsCheckAutoLinkedPersonasData* _data_) {
#line 447 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	switch (_data_->_state_) {
#line 447 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		case 0:
#line 3594 "link-personas.c"
		goto _state_0;
		default:
#line 447 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_assert_not_reached ();
#line 3599 "link-personas.c"
	}
	_state_0:
#line 449 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp0_ = NULL;
#line 449 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp0_ = _data_->self->priv->_linking_props;
#line 449 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp1_ = 0;
#line 449 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp1_ = gee_abstract_map_get_size ((GeeMap*) _data_->_tmp0_);
#line 449 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp2_ = 0;
#line 449 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 449 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_tmp2_ == 0) {
#line 452 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		if (_data_->_state_ == 0) {
#line 452 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3620 "link-personas.c"
		} else {
#line 452 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3624 "link-personas.c"
		}
#line 452 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_object_unref (_data_->_async_result);
#line 452 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		return FALSE;
#line 3630 "link-personas.c"
	}
#line 455 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp3_ = NULL;
#line 455 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp3_ = _data_->i;
#line 455 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp4_ = NULL;
#line 455 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp4_ = folks_individual_get_personas (_data_->_tmp3_);
#line 455 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp5_ = NULL;
#line 455 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 455 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp6_ = 0;
#line 455 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp6_ = gee_collection_get_size ((GeeCollection*) _data_->_tmp5_);
#line 455 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp7_ = 0;
#line 455 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 455 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_tmp7_ > 1) {
#line 3654 "link-personas.c"
		{
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp8_ = NULL;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp8_ = _data_->i;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp9_ = NULL;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp9_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _data_->_tmp8_);
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp10_ = NULL;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp10_ = _data_->_tmp9_;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp11_ = NULL;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp11_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp10_);
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_email_it = _data_->_tmp11_;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			while (TRUE) {
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp12_ = NULL;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp12_ = _data_->_email_it;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp13_ = FALSE;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp13_ = gee_iterator_next (_data_->_tmp12_);
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				if (!_data_->_tmp13_) {
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					break;
#line 3688 "link-personas.c"
				}
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp14_ = NULL;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp14_ = _data_->_email_it;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp15_ = NULL;
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp15_ = gee_iterator_get (_data_->_tmp14_);
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->email = (FolksEmailFieldDetails*) _data_->_tmp15_;
#line 459 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp16_ = NULL;
#line 459 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp16_ = _data_->email;
#line 459 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp17_ = NULL;
#line 459 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp17_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _data_->_tmp16_);
#line 459 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp18_ = NULL;
#line 459 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp18_ = _data_->_tmp17_;
#line 459 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp19_ = NULL;
#line 459 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp19_ = _data_->self->priv->_auto_linkable_email;
#line 459 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				if (g_strcmp0 ((const gchar*) _data_->_tmp18_, _data_->_tmp19_) == 0) {
#line 461 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					_data_->_tmp20_ = NULL;
#line 461 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					_data_->_tmp20_ = _data_->self->priv->_linking_props;
#line 461 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp20_, "prop1", NULL);
#line 3724 "link-personas.c"
				}
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_g_object_unref0 (_data_->email);
#line 3728 "link-personas.c"
			}
#line 457 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->_email_it);
#line 3732 "link-personas.c"
		}
		{
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp21_ = NULL;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp21_ = _data_->i;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp22_ = NULL;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp22_ = folks_im_details_get_im_addresses ((FolksImDetails*) _data_->_tmp21_);
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp23_ = NULL;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp23_ = _data_->_tmp22_;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp24_ = NULL;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp24_ = gee_multi_map_get_keys (_data_->_tmp23_);
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp25_ = NULL;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp25_ = _data_->_tmp24_;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp26_ = NULL;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp26_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp25_);
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp27_ = NULL;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_tmp27_ = _data_->_tmp26_;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->_tmp25_);
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_data_->_proto1_it = _data_->_tmp27_;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			while (TRUE) {
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp28_ = NULL;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp28_ = _data_->_proto1_it;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp29_ = FALSE;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp29_ = gee_iterator_next (_data_->_tmp28_);
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				if (!_data_->_tmp29_) {
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					break;
#line 3781 "link-personas.c"
				}
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp30_ = NULL;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp30_ = _data_->_proto1_it;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp31_ = NULL;
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp31_ = gee_iterator_get (_data_->_tmp30_);
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->proto1 = (gchar*) _data_->_tmp31_;
#line 467 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp32_ = NULL;
#line 467 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp32_ = _data_->i;
#line 467 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp33_ = NULL;
#line 467 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp33_ = folks_im_details_get_im_addresses ((FolksImDetails*) _data_->_tmp32_);
#line 467 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp34_ = NULL;
#line 467 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp34_ = _data_->_tmp33_;
#line 467 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp35_ = NULL;
#line 467 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp35_ = _data_->proto1;
#line 467 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp36_ = NULL;
#line 467 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->_tmp36_ = gee_multi_map_get (_data_->_tmp34_, _data_->_tmp35_);
#line 467 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_data_->im_fds1 = _data_->_tmp36_;
#line 3815 "link-personas.c"
				{
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					_data_->_tmp37_ = NULL;
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					_data_->_tmp37_ = _data_->im_fds1;
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					_data_->_tmp38_ = NULL;
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					_data_->_tmp38_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp37_);
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					_data_->_im_fd1_it = _data_->_tmp38_;
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					while (TRUE) {
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp39_ = NULL;
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp39_ = _data_->_im_fd1_it;
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp40_ = FALSE;
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp40_ = gee_iterator_next (_data_->_tmp39_);
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						if (!_data_->_tmp40_) {
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							break;
#line 3841 "link-personas.c"
						}
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp41_ = NULL;
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp41_ = _data_->_im_fd1_it;
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp42_ = NULL;
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp42_ = gee_iterator_get (_data_->_tmp41_);
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->im_fd1 = (FolksImFieldDetails*) _data_->_tmp42_;
#line 470 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp43_ = NULL;
#line 470 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp43_ = _data_->im_fd1;
#line 470 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp44_ = NULL;
#line 470 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp44_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _data_->_tmp43_);
#line 470 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp45_ = NULL;
#line 470 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp45_ = _data_->_tmp44_;
#line 470 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp46_ = NULL;
#line 470 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_data_->_tmp46_ = _data_->self->priv->_auto_linkable_email;
#line 470 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						if (g_strcmp0 ((const gchar*) _data_->_tmp45_, _data_->_tmp46_) == 0) {
#line 472 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp47_ = NULL;
#line 472 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							_data_->_tmp47_ = _data_->self->priv->_linking_props;
#line 472 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
							gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp47_, "prop2", NULL);
#line 3877 "link-personas.c"
						}
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
						_g_object_unref0 (_data_->im_fd1);
#line 3881 "link-personas.c"
					}
#line 468 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
					_g_object_unref0 (_data_->_im_fd1_it);
#line 3885 "link-personas.c"
				}
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_g_object_unref0 (_data_->im_fds1);
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
				_g_free0 (_data_->proto1);
#line 3891 "link-personas.c"
			}
#line 465 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
			_g_object_unref0 (_data_->_proto1_it);
#line 3895 "link-personas.c"
		}
	}
#line 478 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp48_ = NULL;
#line 478 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp48_ = _data_->self->priv->_linking_props;
#line 478 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp49_ = 0;
#line 478 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp49_ = gee_abstract_map_get_size ((GeeMap*) _data_->_tmp48_);
#line 478 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp50_ = 0;
#line 478 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_data_->_tmp50_ = _data_->_tmp49_;
#line 478 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_tmp50_ == 0) {
#line 480 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp51_ = NULL;
#line 480 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		_data_->_tmp51_ = _data_->self->priv->_main_loop;
#line 480 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_main_loop_quit (_data_->_tmp51_);
#line 3918 "link-personas.c"
	}
#line 447 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	if (_data_->_state_ == 0) {
#line 447 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3924 "link-personas.c"
	} else {
#line 447 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3928 "link-personas.c"
	}
#line 447 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_object_unref (_data_->_async_result);
#line 447 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return FALSE;
#line 3934 "link-personas.c"
}


static void link_personas_tests_class_init (LinkPersonasTestsClass * klass) {
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	link_personas_tests_parent_class = g_type_class_peek_parent (klass);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_type_class_add_private (klass, sizeof (LinkPersonasTestsPrivate));
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	EDS_TEST_TEST_CASE_CLASS (klass)->create_backend = link_personas_tests_real_create_backend;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	G_OBJECT_CLASS (klass)->finalize = link_personas_tests_finalize;
#line 3947 "link-personas.c"
}


static void link_personas_tests_instance_init (LinkPersonasTests * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv = LINK_PERSONAS_TESTS_GET_PRIVATE (self);
#line 39 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = g_strdup ("someone-1@jabber.example.org");
#line 39 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_im_address_1 = _tmp0_;
#line 40 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp1_ = g_strdup ("someone-2@jabber.example.org");
#line 40 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_im_address_2 = _tmp1_;
#line 41 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp2_ = g_strdup ("the.cool.dude@gmail.tld");
#line 41 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_auto_linkable_email = _tmp2_;
#line 50 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self->priv->_test_num = -1;
#line 3971 "link-personas.c"
}


static void link_personas_tests_finalize (GObject* obj) {
	LinkPersonasTests * self;
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LINK_PERSONAS_TESTS, LinkPersonasTests);
#line 35 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 36 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 37 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 38 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 39 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (self->priv->_im_address_1);
#line 40 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (self->priv->_im_address_2);
#line 41 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (self->priv->_auto_linkable_email);
#line 45 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (self->priv->_persona_iid_1);
#line 46 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_free0 (self->priv->_persona_iid_2);
#line 47 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (self->priv->_personas);
#line 48 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (self->priv->_linking_props);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	G_OBJECT_CLASS (link_personas_tests_parent_class)->finalize (obj);
#line 4003 "link-personas.c"
}


GType link_personas_tests_get_type (void) {
	static volatile gsize link_personas_tests_type_id__volatile = 0;
	if (g_once_init_enter (&link_personas_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LinkPersonasTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) link_personas_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LinkPersonasTests), 0, (GInstanceInitFunc) link_personas_tests_instance_init, NULL };
		GType link_personas_tests_type_id;
		link_personas_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "LinkPersonasTests", &g_define_type_info, 0);
		g_once_init_leave (&link_personas_tests_type_id__volatile, link_personas_tests_type_id);
	}
	return link_personas_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	LinkPersonasTests* tests = NULL;
	LinkPersonasTests* _tmp0_ = NULL;
#line 487 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_test_init (&args_length1, &args, NULL);
#line 489 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_tmp0_ = link_personas_tests_new ();
#line 489 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	tests = _tmp0_;
#line 490 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 491 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	g_test_run ();
#line 492 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 494 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	result = 0;
#line 494 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	_g_object_unref0 (tests);
#line 494 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return result;
#line 4041 "link-personas.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 485 "/opt/gnome3/source/folks/tests/eds/link-personas.vala"
	return _vala_main (argv, argc);
#line 4051 "link-personas.c"
}



